@@ -45,13 +45,13 @@ void FileMetadataItemCountTest::initTestCase()
     
     QStandardPaths::setTestModeEnabled(true);
 
-    KConfig balooConfig(QStringLiteral("baloofilerc"), KConfig::NoGlobals);
+    KConfig balooConfig("baloofilerc", KConfig::NoGlobals);
     KConfigGroup balooSettings = balooConfig.group("General");
     // If we use .writePathEntry here, the test will fail.
     balooSettings.writeEntry(QStringLiteral("folders"), QString());
     
     // Ensure show configuration
-    KConfig config(QStringLiteral("baloofileinformationrc"), KConfig::NoGlobals);
+    KConfig config("baloofileinformationrc", KConfig::NoGlobals);
     KConfigGroup settings = config.group("Show");
     const auto keys = settings.keyList();
     for (const auto &key: keys) {
@@ -71,10 +71,7 @@ void FileMetadataItemCountTest::cleanup()
 
 void FileMetadataItemCountTest::testItemCount()
 {
-    // the number of items will increase in the future adding the file creation time field
-    // when the system has KIO 5.58, glibc 2.28, linux 4.11 and a filesystem storing file creation times (btrfs, ext4...)
-    // The expectedItems count will need to be updated
-    const int expectedItems = 20;
+    const int expectedItems = 19;
     const int widgetsPerItem = 2;
     
     QSignalSpy spy(m_widget, &Baloo::FileMetaDataWidget::metaDataRequestFinished);
