@@ -1,5 +1,5 @@
 /*
- * This file is part of the Nepomuk KDE project.
+ * This file is part of the Baloo KDE project.
  * Copyright (C) 2006-2007 Sebastian Trueg <trueg@kde.org>
  *
  * This library is free software; you can redistribute it and/or
@@ -28,9 +28,9 @@
 
 #include "kblocklayout.h"
 
-#include <QtCore/QList>
-#include <QtWidgets/QStyle>
-#include <QtWidgets/QWidget>
+#include <QList>
+#include <QStyle>
+#include <QWidget>
 
 class KBlockLayout::Private
 {
@@ -46,7 +46,7 @@ public:
             return -1;
         } else if (parent->isWidgetType()) {
             QWidget *pw = static_cast<QWidget *>(parent);
-            return pw->style()->pixelMetric(pm, 0, pw);
+            return pw->style()->pixelMetric(pm, nullptr, pw);
         } else {
             return static_cast<QLayout *>(parent)->spacing();
         }
@@ -143,12 +143,12 @@ QLayoutItem *KBlockLayout::takeAt( int index )
     if (index >= 0 && index < d->itemList.size())
         return d->itemList.takeAt(index);
     else
-        return 0;
+        return nullptr;
 }
 
 Qt::Orientations KBlockLayout::expandingDirections() const
 {
-    return 0;
+    return nullptr;
 }
 
 bool KBlockLayout::hasHeightForWidth() const
